@@ -4,26 +4,37 @@ use 5.008003;
 use strict;
 use warnings;
 
-our $VERSION = '1.41';
+our $VERSION = '1.63';
 
 use Audio::TagLib;
 
-our @ISA = qw(Audio::TagLib::Ogg::File);
+use base qw(Audio::TagLib::Ogg::File);
 
-# Preloaded methods go here.
-
-BEGIN : 
-  {
-      no strict 'refs';
-      unless (grep {/^new$/ } keys %__PACKAGE__::) {
-          *Audio::TagLib::Ogg::Vorbis::File:: = *Audio::TagLib::Vorbis::File:: ;
-            
-      }
-  }
+BEGIN{
+=pod
+    no strict 'refs';    ## no critic (ProhibitNoStrict)
+    unless (grep {/^new$/ } keys %__PACKAGE__::) {
+        *Audio::TagLib::Ogg::Vorbis::File:: = *Audio::TagLib::Vorbis::File:: ;
+    }
+=cut
+    $DB::single = 2;
+    my $new = grep { $_ eq 'new' }  keys %__PACKAGE__::;
+    if ( not $new ) {
+        *Audio::TagLib::Ogg::Vorbis::File:: = *Audio::TagLib::Vorbis::File:: ;
+    }
+}
 
 1;
+
 __END__
-# Below is stub documentation for your module. You'd better edit it!
+
+=pod
+
+=begin stopwords
+
+Dongxu
+
+=end stopwords
 
 =head1 NAME
 
@@ -90,9 +101,15 @@ L<Audio::TagLib|Audio::TagLib> L<Ogg::File|Audio::TagLib::Ogg::File>
 
 Dongxu Ma, E<lt>dongxu@cpan.orgE<gt>
 
+=head1 MAINTAINER
+
+Geoffrey Leach GLEACH@cpan.org
+
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2005 by Dongxu Ma
+Copyright (C) 2005-2010 by Dongxu Ma
+
+Copyright (C) 2011 - 2012 Geoffrey Leach
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.7 or,
